@@ -1,7 +1,7 @@
-import datetime
 import json
+from typing import Any, Dict
+from urllib import request
 
-import requests
 from django.core.exceptions import ImproperlyConfigured
 
 from discord_integration.models import DiscordIntegration
@@ -9,12 +9,7 @@ from discord_integration.models import DiscordIntegration
 __all__ = ['discord_message']
 
 
-def timestamp():
-    return datetime.datetime.utcnow().replace(tzinfo=datetime.timezone.utc) \
-                            .replace(microsecond=0).isoformat()
-
-
-def discord_message(message):
+def discord_message(message: Dict[str, Any]) -> None:
     data = DiscordIntegration.get_solo()
 
     if not data.webhook_url:
@@ -26,8 +21,10 @@ def discord_message(message):
     if data.avatar_url and 'avatar_url' not in message:
         message['avatar_url'] = data.avatar_url
 
-    if 'timestamp' not in message:
-        message['timestamp'] = timestamp()
-
-    requests.post(data.webhook_url, data=json.dumps(message),
-                  headers={'Content-Type': 'application/json'})
+    request.urlopen(
+        request.Request(
+            data.webhook_url,
+            data=json.dumps(message).encode('utf-8'),
+            headers={'User-Agent': 'Python/3', 'Content-Type': 'application/json'},
+        ),
+    )
